==> malloryai_sdk-0.1.0.tar.gz: malloryai_sdk-0.1.0/tests/v1/exploits/test_exploits.py <==
import pytest

pytestmark = pytest.mark.asyncio


async def test_list_exploits(api_client):
    """Test list_exploits() API call."""
    response = await api_client.exploits.list_exploits(limit=5)

    assert isinstance(response, dict)
    assert "data" in response and isinstance(response["data"], list)
    assert "total" in response and isinstance(response["total"], int)
    assert "offset" in response and isinstance(response["offset"], int)
    assert "limit" in response and isinstance(response["limit"], int)

    if response["data"]:  # If results exist, validate structure of first entry
        first_config = response["data"][0]
        required_fields = [
            "uuid",
            "created_at",
            "updated_at",
            "description",
            "url",
            "maturity",
            "vulnerabilities",
        ]

        for field in required_fields:
            assert field in first_config, f"Missing expected field: {field}"


async def test_get_exploit(api_client):
    """Test get_exploit() API call."""
    exploit = await api_client.exploits.list_exploits(limit=1)
    response = await api_client.exploits.get_exploit(exploit["data"][0]["uuid"])

    assert isinstance(response, dict)
    required_fields = [
        "uuid",
        "created_at",
        "updated_at",
        "disclosed_at",
        "url",
        "description",
        "maturity",
        "authors",
        "vulnerabilities",
    ]
    for field in required_fields:
        assert field in response, f"Missing expected field: {field}"

==> malloryai_sdk-0.3.0.tar.gz: malloryai_sdk-0.3.0/tests/v1/exploits/test_exploits.py <==
import pytest

pytestmark = pytest.mark.asyncio


async def test_list_exploits(api_client):
    """Test list_exploits() API call (async)."""
    response = await api_client.exploits.list_exploits(limit=5)

    assert isinstance(response, dict)
    assert "data" in response and isinstance(response["data"], list)
    assert "total" in response and isinstance(response["total"], int)
    assert "offset" in response and isinstance(response["offset"], int)
    assert "limit" in response and isinstance(response["limit"], int)

    if response["data"]:
        first_config = response["data"][0]
        required_fields = [
            "uuid",
            "created_at",
            "updated_at",
            "description",
            "url",
            "maturity",
            "vulnerabilities",
        ]
        for field in required_fields:
            assert field in first_config, f"Missing expected field: {field}"


async def test_get_exploit(api_client):
    """Test get_exploit() API call (async)."""
    exploit = await api_client.exploits.list_exploits(limit=1)
    response = await api_client.exploits.get_exploit(exploit["data"][0]["uuid"])

    assert isinstance(response, dict)
    required_fields = [
        "uuid",
        "created_at",
        "updated_at",
        "disclosed_at",
        "url",
        "description",
        "maturity",
        "authors",
        "vulnerabilities",
    ]
    for field in required_fields:
        assert field in response, f"Missing expected field: {field}"


def test_list_exploits_sync(api_client):
    """Test list_exploits_sync() API call (sync)."""
    response = api_client.exploits.list_exploits_sync(limit=5)

    assert isinstance(response, dict)
    assert "data" in response and isinstance(response["data"], list)
    assert "total" in response and isinstance(response["total"], int)
    assert "offset" in response and isinstance(response["offset"], int)
    assert "limit" in response and isinstance(response["limit"], int)

    if response["data"]:
        first_config = response["data"][0]
        required_fields = [
            "uuid",
            "created_at",
            "updated_at",
            "description",
            "url",
            "maturity",
            "vulnerabilities",
        ]
        for field in required_fields:
            assert field in first_config, f"Missing expected field: {field}"


def test_get_exploit_sync(api_client):
    """Test get_exploit_sync() API call (sync)."""
    exploit = api_client.exploits.list_exploits_sync(limit=1)
    response = api_client.exploits.get_exploit_sync(exploit["data"][0]["uuid"])

    assert isinstance(response, dict)
    required_fields = [
        "uuid",
        "created_at",
        "updated_at",
        "disclosed_at",
        "url",
        "description",
        "maturity",
        "authors",
        "vulnerabilities",
    ]
    for field in required_fields:
        assert field in response, f"Missing expected field: {field}"
